==> haskell-iproute-1.7.15-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-iproute.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 iproute
version:              1.7.15
visibility:           public
id:                   iproute-1.7.15-4bTvgmu3pwnLw6WjpGAAua
key:                  iproute-1.7.15-4bTvgmu3pwnLw6WjpGAAua
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             http://www.mew.org/~kazu/proj/iproute/
synopsis:             IP Routing Table
description:
    IP Routing Table is a tree of IP ranges
    to search one of them on the longest
    match base. It is a kind of TRIE with one
    way branching removed. Both IPv4 and IPv6
    are supported.

category:             Algorithms, Network
abi:                  5522bace456b1e5ece0b2de25f21e98f
exposed:              True
exposed-modules:
    Data.IP Data.IP.Builder Data.IP.Internal Data.IP.RouteTable
    Data.IP.RouteTable.Internal

hidden-modules:       Data.IP.Addr Data.IP.Mask Data.IP.Op Data.IP.Range
import-dirs:          /usr/lib/ghc-9.4.8/site-local/iproute-1.7.15
library-dirs:         /usr/lib/ghc-9.4.8/site-local/iproute-1.7.15
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/iproute-1.7.15
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-iproute
hs-libraries:         HSiproute-1.7.15-4bTvgmu3pwnLw6WjpGAAua
depends:
    appar-0.1.8-GWpFBSBbC0w8yHmWJHobgf base-4.17.2.1
    byteorder-1.0.4-GnZZPnCtMLjHLa4McP5dl3 bytestring-0.11.5.3
    containers-0.6.7 network-3.1.4.0-2CBRys83VnCFTvPdAqVbyS

haddock-interfaces:   /usr/share/doc/haskell-iproute/html/iproute.haddock
haddock-html:         /usr/share/doc/haskell-iproute/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-iproute-1.7.15-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-iproute.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 iproute
version:              1.7.15
visibility:           public
id:                   iproute-1.7.15-CnWUyo1uoQKIAdvIUppwo5
key:                  iproute-1.7.15-CnWUyo1uoQKIAdvIUppwo5
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             http://www.mew.org/~kazu/proj/iproute/
synopsis:             IP Routing Table
description:
    IP Routing Table is a tree of IP ranges
    to search one of them on the longest
    match base. It is a kind of TRIE with one
    way branching removed. Both IPv4 and IPv6
    are supported.

category:             Algorithms, Network
abi:                  6c4e3da80fd7cf0308bc0151242998ae
exposed:              True
exposed-modules:
    Data.IP Data.IP.Builder Data.IP.Internal Data.IP.RouteTable
    Data.IP.RouteTable.Internal

hidden-modules:       Data.IP.Addr Data.IP.Mask Data.IP.Op Data.IP.Range
import-dirs:          /usr/lib/ghc-9.4.8/site-local/iproute-1.7.15
library-dirs:         /usr/lib/ghc-9.4.8/site-local/iproute-1.7.15
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/iproute-1.7.15
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-iproute
hs-libraries:         HSiproute-1.7.15-CnWUyo1uoQKIAdvIUppwo5
depends:
    appar-0.1.8-GWpFBSBbC0w8yHmWJHobgf base-4.17.2.1
    byteorder-1.0.4-GnZZPnCtMLjHLa4McP5dl3 bytestring-0.11.5.3
    containers-0.6.7 network-3.1.4.0-Kct0mSlvmXmLu6Ylw4X71A

haddock-interfaces:   /usr/share/doc/haskell-iproute/html/iproute.haddock
haddock-html:         /usr/share/doc/haskell-iproute/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
